# Artificial Neural Network for brain tumor detection
![License](https://img.shields.io/badge/License-GPL_2.0-green)
![python](https://img.shields.io/badge/Python-3.9.12-blue)
![Numpy](https://img.shields.io/badge/Numpy-1.21.5-blue)
![Skimage](https://img.shields.io/badge/Scikit_Image-0.19.2-blue)
![Sklearn](https://img.shields.io/badge/Scikit_Learn-1.0.2-blue)
![Matplotlib](https://img.shields.io/badge/Matplotlib-3.5.1-blue)
![Pickle](https://img.shields.io/badge/-Pickle-blue)
![Random](https://img.shields.io/badge/-Random-blue)

# Index
This is a project that aims to implement an artificial neural network for classification of brain tomography images.

<h4 align="center"> 
	🚧  Status 🚀 Under construction...  🚧
</h4>

# Infos
This project is a manual implementation of a neural network, based on the mutilayer perceptron model for classifying features of brain tomography images. The activation function implemented in this network was the sigmoid, the characteristics of the images are extracted through the Gray Level Co-Occurrence Matrix (GLCM).

The image dataset that was used is public and available at https://www.kaggle.com/datasets/preetviradiya/brian-tumor-dataset

# Pré-requeriments
...


